package main

import (
	"context"
	"os"

	"git.3crabs.ru/save_my_money/smm_tg/internal/modules/messenger/telegram"
	"git.3crabs.ru/save_my_money/smm_tg/internal/services/bot"
	"git.3crabs.ru/save_my_money/smm_tg/internal/services/bot/bot_ping"
	"git.3crabs.ru/save_my_money/smm_tg/internal/services/listener"
	"github.com/joho/godotenv"
)

func main() {
	// try get sysenv
	telegarmToken := os.Getenv("BOT_TOKEN")
	if len(telegarmToken) == 0 {
		if err := godotenv.Load("../../.env"); err != nil {
			panic(err)
		}
		telegarmToken = os.Getenv("BOT_TOKEN")
	}
	if len(telegarmToken) == 0 {
		panic("empty bot token")
	}

	messengerTelegram, err := telegram.NewMessengerTelegram(telegarmToken)
	if err != nil {
		panic(err)
	}

	listenerService := listener.ListenerService{
		Messenger: messengerTelegram,
		Bots: []bot.IBot{
			bot_ping.NewBotPing(messengerTelegram),
		},
	}
	ctx := context.Background()
	listenerService.Run(ctx)
}
